@@ -594,8 +594,34 @@ generate:
 	return -EIO;
 }
 
-static int network_load_psk(struct network *network, bool need_passphrase)
+static inline bool __bss_is_sae(const struct scan_bss *bss,
+						const struct ie_rsn_info *rsn)
 {
+	if (rsn->akm_suites & IE_RSN_AKM_SUITE_SAE_SHA256)
+		return true;
+
+	return false;
+}
+
+static bool bss_is_sae(const struct scan_bss *bss)
+{
+	struct ie_rsn_info rsn;
+
+	memset(&rsn, 0, sizeof(rsn));
+	scan_bss_get_rsn_info(bss, &rsn);
+
+	return __bss_is_sae(bss, &rsn);
+}
+
+static int network_load_psk(struct network *network, struct scan_bss *bss)
+{
+	/*
+	 * A legacy psk file may only contain the PreSharedKey entry. For SAE
+	 * networks the raw Passphrase is required. So in this case where
+	 * the psk is found but no Passphrase, we ask the agent.  The psk file
+	 * will then be re-written to contain the raw passphrase.
+	 */
+	bool is_sae = bss_is_sae(bss);
 	const char *ssid = network_get_ssid(network);
 	enum security security = network_get_security(network);
 	size_t psk_len;
@@ -616,7 +642,7 @@ static int network_load_psk(struct network *network, bool need_passphrase)
 	}
 
 	/* PSK can be generated from the passphrase but not the other way */
-	if (!psk || need_passphrase) {
+	if (!psk || is_sae) {
 		if (!passphrase)
 			return -ENOKEY;
 
@@ -764,10 +790,8 @@ void network_set_info(struct network *network, struct network_info *info)
 		network->info = NULL;
 	}
 
-#ifdef HAVE_DBUS
 	l_dbus_property_changed(dbus_get_bus(), network_get_path(network),
 					IWD_NETWORK_INTERFACE, "KnownNetwork");
-#endif
 }
 
 void network_set_force_default_owe_group(struct network *network)
@@ -780,25 +804,6 @@ bool network_get_force_default_owe_group(struct network *network)
 	return network->force_default_owe_group;
 }
 
-static inline bool __bss_is_sae(const struct scan_bss *bss,
-						const struct ie_rsn_info *rsn)
-{
-	if (rsn->akm_suites & IE_RSN_AKM_SUITE_SAE_SHA256)
-		return true;
-
-	return false;
-}
-
-static bool bss_is_sae(const struct scan_bss *bss)
-{
-	struct ie_rsn_info rsn;
-
-	memset(&rsn, 0, sizeof(rsn));
-	scan_bss_get_rsn_info(bss, &rsn);
-
-	return __bss_is_sae(bss, &rsn);
-}
-
 int network_can_connect_bss(struct network *network, const struct scan_bss *bss)
 {
 	struct station *station = network->station;
@@ -961,7 +966,7 @@ int network_autoconnect(struct network *network, struct scan_bss *bss)
 
 	switch (security) {
 	case SECURITY_PSK:
-		ret = network_load_psk(network, bss_is_sae(bss));
+		ret = network_load_psk(network, bss);
 		if (ret < 0)
 			goto close_settings;
 
@@ -993,7 +998,8 @@ int network_autoconnect(struct network *network, struct scan_bss *bss)
 		return -ENOTSUP;
 	}
 
-	return __station_connect_network(station, network, bss);
+	return __station_connect_network(station, network, bss,
+						STATION_STATE_CONNECTING_AUTO);
 
 close_settings:
 	network_settings_close(network);
@@ -1286,20 +1292,13 @@ static struct l_dbus_message *network_connect_psk(struct network *network,
 					struct l_dbus_message *message)
 {
 	struct station *station = network->station;
-	/*
-	 * A legacy psk file may only contain the PreSharedKey entry. For SAE
-	 * networks the raw Passphrase is required. So in this case where
-	 * the psk is found but no Passphrase, we ask the agent.  The psk file
-	 * will then be re-written to contain the raw passphrase.
-	 */
-	bool need_passphrase = bss_is_sae(bss);
 
 	if (!network_settings_load(network)) {
 		network->settings = l_settings_new();
 		network->ask_passphrase = true;
 	} else if (!network->ask_passphrase)
 		network->ask_passphrase =
-			network_load_psk(network, need_passphrase) < 0;
+			network_load_psk(network, bss) < 0;
 
 	l_debug("ask_passphrase: %s",
 		network->ask_passphrase ? "true" : "false");
@@ -1539,7 +1538,6 @@ static struct l_dbus_message *network_connect_8021x(struct network *network,
 	r = eap_check_settings(network->settings, network->secrets, "EAP-",
 				true, &missing_secrets);
 	if (r) {
-#ifdef HAVE_DBUS
 		if (r == -EUNATCH)
 			reply = dbus_error_not_available(message);
 		else if (r == -ENOTSUP)
@@ -1548,7 +1546,6 @@ static struct l_dbus_message *network_connect_8021x(struct network *network,
 			reply = dbus_error_failed(message);
 		else
 			reply = dbus_error_not_configured(message);
-#endif
 
 		goto error;
 	}
@@ -1559,9 +1556,7 @@ static struct l_dbus_message *network_connect_8021x(struct network *network,
 
 	if (l_queue_isempty(missing_secrets)) {
 		if (!network_set_8021x_secrets(network)) {
-#ifdef HAVE_DBUS
 			reply = dbus_error_failed(message);
-#endif
 
 			goto error;
 		}
@@ -1575,9 +1570,7 @@ static struct l_dbus_message *network_connect_8021x(struct network *network,
 				eap_secret_done))
 		return NULL;
 
-#ifdef HAVE_DBUS
 	reply = dbus_error_no_agent(message);
-#endif
 
 error:
 	network_settings_close(network);
@@ -1795,7 +1788,6 @@ static bool network_property_get_known_network(struct l_dbus *dbus,
 
 bool network_register(struct network *network, const char *path)
 {
-#ifdef HAVE_DBUS
 	if (!l_dbus_object_add_interface(dbus_get_bus(), path,
 					IWD_NETWORK_INTERFACE, network)) {
 		l_info("Unable to register %s interface",
@@ -1807,7 +1799,6 @@ bool network_register(struct network *network, const char *path)
 					L_DBUS_INTERFACE_PROPERTIES, network))
 		l_info("Unable to register %s interface",
 						L_DBUS_INTERFACE_PROPERTIES);
-#endif
 
 	network->object_path = l_strdup(path);
 
@@ -1816,9 +1807,7 @@ bool network_register(struct network *network, const char *path)
 
 static void network_unregister(struct network *network, int reason)
 {
-#ifdef HAVE_DBUS
 	struct l_dbus *dbus = dbus_get_bus();
-#endif
 
 	if (network->connect_after_anqp)
 		dbus_pending_reply(&network->connect_after_anqp,
@@ -1831,9 +1820,7 @@ static void network_unregister(struct network *network, int reason)
 	agent_request_cancel(network->agent_request, reason);
 	network_settings_close(network);
 
-#ifdef HAVE_DBUS
 	l_dbus_unregister_object(dbus, network->object_path);
-#endif
 
 	l_free(network->object_path);
 	network->object_path = NULL;
@@ -2035,11 +2022,9 @@ static void event_watch_changed(enum station_event state,
 		l_debug("ANQP complete, resuming connect to %s", network->ssid);
 
 		if (!network_settings_load(network)) {
-#ifdef HAVE_DBUS
 			reply = dbus_error_not_configured(
 						network->connect_after_anqp);
 			dbus_pending_reply(&network->connect_after_anqp, reply);
-#endif
 			return;
 		}
 
@@ -2047,12 +2032,10 @@ static void event_watch_changed(enum station_event state,
 					network_bss_select(network, true),
 					network->connect_after_anqp);
 
-#ifdef HAVE_DBUS
 		if (reply)
 			l_dbus_send(dbus_get_bus(), reply);
 
 		l_dbus_message_unref(network->connect_after_anqp);
-#endif
 		network->connect_after_anqp = NULL;
 
 		break;
@@ -2101,12 +2084,10 @@ static void setup_network_interface(struct l_dbus_interface *interface)
 
 static int network_init(void)
 {
-#ifdef HAVE_DBUS
 	if (!l_dbus_register_interface(dbus_get_bus(), IWD_NETWORK_INTERFACE,
 					setup_network_interface, NULL, false))
 		l_error("Unable to register %s interface",
 						IWD_NETWORK_INTERFACE);
-#endif
 
 	known_networks_watch =
 		known_networks_watch_add(known_networks_changed, NULL, NULL);
@@ -2124,9 +2105,7 @@ static void network_exit(void)
 	station_remove_event_watch(event_watch);
 	event_watch = 0;
 
-#ifdef HAVE_DBUS
 	l_dbus_unregister_interface(dbus_get_bus(), IWD_NETWORK_INTERFACE);
-#endif
 }
 
 IWD_MODULE(network, network_init, network_exit)
